class_mapping: The mapping class

class_mappingR Documentation

The mapping class

Description

The mapping class holds a list of quoted expressions (quosures) or constants. An object is typically constructed using the aes() function.

Usage

class_mapping(x = list(), ..., env = globalenv())

Arguments

x

A list of quosures and constants.

...

Reserved for future expansion.

env

An environment for symbols that are not quosures or constants.


ggplot2 documentation built on April 22, 2026, 5:10 p.m.