Skip to content

This statistic layer can take multiple stats and chain these together to transform the data in a series of computations.

Usage

stat_chain(
  mapping = NULL,
  data = NULL,
  geom = "path",
  position = "identity",
  ...,
  stats = "identity",
  na.rm = FALSE,
  show.legend = NA,
  inherit.aes = TRUE
)

Arguments

mapping

Set of aesthetic mappings created by aes(). If specified and inherit.aes = TRUE (the default), it is combined with the default mapping at the top level of the plot. You must supply mapping if there is no plot mapping.

data

The data to be displayed in this layer. There are three options:

  • NULL (default): the data is inherited from the plot data as specified in the call to ggplot().

  • A data.frame, or other object, will override the plot data. All objects will be fortified to produce a data frame. See fortify() for which variables will be created.

  • A function will be called with a single argument, the plot data. The return value must be a data.frame, and will be used as the layer data. A function can be created from a formula (e.g. ~ head(.x, 10)).

geom

The geometric object to use to display the data for this layer. When using a stat_*() function to construct a layer, the geom argument can be used to override the default coupling between stats and geoms. The geom argument accepts the following:

  • A Geom ggproto subclass, for example GeomPoint.

  • A string naming the geom. To give the geom as a string, strip the function name of the geom_ prefix. For example, to use geom_point(), give the geom as "point".

  • For more information and other ways to specify the geom, see the layer geom documentation.

position

A position adjustment to use on the data for this layer. This can be used in various ways, including to prevent overplotting and improving the display. The position argument accepts the following:

  • The result of calling a position function, such as position_jitter(). This method allows for passing extra arguments to the position.

  • A string naming the position adjustment. To give the position as a string, strip the function name of the position_ prefix. For example, to use position_jitter(), give the position as "jitter".

  • For more information and other ways to specify the position, see the layer position documentation.

...

Other arguments passed on to layer()'s params argument. These arguments broadly fall into one of 4 categories below. Notably, further arguments to the position argument, or aesthetics that are required can not be passed through .... Unknown arguments that are not part of the 4 categories below are ignored.

  • Static aesthetics that are not mapped to a scale, but are at a fixed value and apply to the layer as a whole. For example, colour = "red" or linewidth = 3. The geom's documentation has an Aesthetics section that lists the available options. The 'required' aesthetics cannot be passed on to the params. Please note that while passing unmapped aesthetics as vectors is technically possible, the order and required length is not guaranteed to be parallel to the input data.

  • When constructing a layer using a stat_*() function, the ... argument can be used to pass on parameters to the geom part of the layer. An example of this is stat_density(geom = "area", outline.type = "both"). The geom's documentation lists which parameters it can accept.

  • Inversely, when constructing a layer using a geom_*() function, the ... argument can be used to pass on parameters to the stat part of the layer. An example of this is geom_area(stat = "density", adjust = 0.5). The stat's documentation lists which parameters it can accept.

  • The key_glyph argument of layer() may also be passed on through .... This can be one of the functions described as key glyphs, to change the display of the layer in the legend.

stats

A character vector or list of statistical transformations to use for this layer. Every element needs to be one of the following:

  • A Stat ggproto subclass, for example StatCount

  • A string naming the stat. To give the stat as a string, strip the function name of the stat_ prefix. For example, to use stat_count(), give the stat as "count".

  • The result of link_stat() to pass parameters or mapping instructions.

na.rm

If FALSE, the default, missing values are removed with a warning. If TRUE, missing values are silently removed.

show.legend

Logical. Should this layer be included in the legends? NA, the default, includes if any aesthetics are mapped. FALSE never includes, and TRUE always includes. It can also be a named logical vector to finely select the aesthetics to display. To include legend keys for all levels, even when no data exists, use TRUE. If NA, all levels are shown in legend, but unobserved levels are omitted.

inherit.aes

If FALSE, overrides the default aesthetics, rather than combining with them. This is most useful for helper functions that define both data and aesthetics and shouldn't inherit behaviour from the default plot specification, e.g. annotation_borders().

Details

The procedure in which stats are chained are as follows. First, the layer-level, undelayed aesthetics in the mapping argument are evaluated. The data that results from that evaluation is passed to the first stat in the stats argument to perform that stat's computation. If that first stat is a link_stat with an after.stat component, the after.stat component is evaluated before passing on the data to the next stat in the stats argument. The next components in the stats argument work the same: the data is passed on to compute the stat, then after.stat is evaluated. In essence, the after.stat allows control over how computed variables are passed to the next stat in the chain. Finally, once all components in the stats arguments have been handled, the staged after stat components of the layer-level mapping is evaluated. Per usual, the data are then handled by the position and geom parts of a layer.

See also

Examples

p <- ggplot(mpg, aes(displ, colour = drv))
# Binning unique observations
p + stat_chain(stats = c("unique", "bin"))
#> `stat_bin()` using `bins = 30`. Pick better value `binwidth`.

# Controlling parameters
p + stat_chain(
  stats = list("unique", link_stat("bin", bins = 10))
)

# Evaluate expressions after computing stats
p + stat_chain(stats = list(
  link_stat("unique",  after.stat = aes(x = x + 1)),
  link_stat("density", after.stat = aes(y = density))
))

# Note that the last `after.stat` argument serves the same role as the
# `after_stat()` function in the layer mapping, so the following is
# equivalent to the previous plot
p + stat_chain(
  mapping = aes(y = after_stat(density)),
  stats = list(link_stat("unique", after.stat = aes(x = x + 1)), "density")
)