The ggplot built class is an intermediate class and represents a processed
ggplot object ready for rendering. It is constructed by calling
ggplot_build() on a ggplot object and is not meant to be
instantiated directly. The class can be rendered to a gtable object by
calling the ggplot_gtable() function on a ggplot built class object.