R/all-classes.R
class_labels.Rd
The labels class holds a list with label information to display as titles of plot components. The preferred way to construct an object of the labels class is to use the labs() function.
labs()
class_labels(labels = list(), ...)
A named list.
Reserved for future expansion.
All members of labels are expected to be named and names should be unique.
labels