The mapping class holds a list of quoted expressions
(quosures) or constants. An object is typically
constructed using the aes() function.
Arguments
- x
A list of quosures and constants.
- ...
Reserved for future expansion.
- env
An environment for symbols that are not quosures or constants.