This is a helper function for stat_chain() to pass parameters and declare
mappings.
Usage
link_stat(stat, ..., after.stat = aes())Arguments
- stat
The statistical transformation to use on the data. The
statargument accepts the following:A
Statggproto subclass, for exampleStatCount.A string naming the stat. To give the stat as a string, strip the function name of the
stat_prefix. For example, forstat_count(), give the string"count".
- ...
Other arguments passed to the stat as a parameter.
- after.stat
Set of aesthetic mappings created by
aes()to be evaluated only after the stat has been computed.